package com.zjsgfa.project.zjsgfa.service;

import java.util.List;
import com.zjsgfa.project.zjsgfa.domain.SjLjfzqk;
import com.zjsgfa.project.zjsgfa.domain.SjLjjw;

/**
 * 邻井复杂情况Service接口
 * 
 * @author ruoyi
 * @date 2026-02-04
 */
public interface ISjLjfzqkService 
{
    /**
     * 查询邻井复杂情况
     * 
     * @param id 邻井复杂情况主键
     * @return 邻井复杂情况
     */
    public SjLjfzqk selectSjLjfzqkById(Long id);

    /**
     * 查询邻井复杂情况列表
     * 
     * @param sjLjfzqk 邻井复杂情况
     * @return 邻井复杂情况集合
     */
    public List<SjLjfzqk> selectSjLjfzqkList(SjLjfzqk sjLjfzqk);

    /**
     * 新增邻井复杂情况
     * 
     * @param sjLjfzqk 邻井复杂情况
     * @return 结果
     */
    public int insertSjLjfzqk(SjLjfzqk sjLjfzqk);

    /**
     * 修改邻井复杂情况
     * 
     * @param sjLjfzqk 邻井复杂情况
     * @return 结果
     */
    public int updateSjLjfzqk(SjLjfzqk sjLjfzqk);

    /**
     * 批量删除邻井复杂情况
     * 
     * @param ids 需要删除的邻井复杂情况主键集合
     * @return 结果
     */
    public int deleteSjLjfzqkByIds(Long[] ids);

    /**
     * 删除邻井复杂情况信息
     * 
     * @param id 邻井复杂情况主键
     * @return 结果
     */
    public int deleteSjLjfzqkById(Long id);

    int insertSjLjfzqkBatch(List<SjLjjw> list);

}
