package com.zjsgfa.project.zjsgfa.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.zjsgfa.project.zjsgfa.domain.SjLjjw;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zjsgfa.framework.aspectj.lang.annotation.Log;
import com.zjsgfa.framework.aspectj.lang.enums.BusinessType;
import com.zjsgfa.project.zjsgfa.domain.SjLjfzqk;
import com.zjsgfa.project.zjsgfa.service.ISjLjfzqkService;
import com.zjsgfa.framework.web.controller.BaseController;
import com.zjsgfa.framework.web.domain.AjaxResult;
import com.zjsgfa.common.utils.poi.ExcelUtil;
import com.zjsgfa.framework.web.page.TableDataInfo;

/**
 * 邻井复杂情况Controller
 * 
 * @author ruoyi
 * @date 2026-02-04
 */
@RestController
@RequestMapping("/system/sjLjfzqk")
public class SjLjfzqkController extends BaseController
{
    @Autowired
    private ISjLjfzqkService sjLjfzqkService;

    /**
     * 查询邻井复杂情况列表
     */
    //@PreAuthorize("@ss.hasPermi('system:sjLjfzqk:list')")
    @GetMapping("/list")
    public TableDataInfo list(SjLjfzqk sjLjfzqk)
    {
        startPage();
        List<SjLjfzqk> list = sjLjfzqkService.selectSjLjfzqkList(sjLjfzqk);
        return getDataTable(list);
    }

    /**
     * 导出邻井复杂情况列表
     */
    //@PreAuthorize("@ss.hasPermi('system:sjLjfzqk:export')")
    @Log(title = "邻井复杂情况", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SjLjfzqk sjLjfzqk)
    {
        List<SjLjfzqk> list = sjLjfzqkService.selectSjLjfzqkList(sjLjfzqk);
        ExcelUtil<SjLjfzqk> util = new ExcelUtil<SjLjfzqk>(SjLjfzqk.class);
        util.exportExcel(response, list, "邻井复杂情况数据");
    }

    /**
     * 获取邻井复杂情况详细信息
     */
    //@PreAuthorize("@ss.hasPermi('system:sjLjfzqk:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(sjLjfzqkService.selectSjLjfzqkById(id));
    }

    /**
     * 新增邻井复杂情况
     */
    //@PreAuthorize("@ss.hasPermi('system:sjLjfzqk:add')")
    @Log(title = "邻井复杂情况", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SjLjfzqk sjLjfzqk)
    {
        return toAjax(sjLjfzqkService.insertSjLjfzqk(sjLjfzqk));
    }

    /**
     * 修改邻井复杂情况
     */
    //@PreAuthorize("@ss.hasPermi('system:sjLjfzqk:edit')")
    @Log(title = "邻井复杂情况", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SjLjfzqk sjLjfzqk)
    {
        return toAjax(sjLjfzqkService.updateSjLjfzqk(sjLjfzqk));
    }

    /**
     * 删除邻井复杂情况
     */
    //@PreAuthorize("@ss.hasPermi('system:sjLjfzqk:remove')")
    @Log(title = "邻井复杂情况", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(sjLjfzqkService.deleteSjLjfzqkByIds(ids));
    }




    @PostMapping("/pladd2Ljfzqk")
    public AjaxResult pladd2Ljfzqk(@RequestBody List<SjLjjw> list) throws Exception
    {
        return toAjax(sjLjfzqkService.insertSjLjfzqkBatch(list));
    }




}
